@@ -48,14 +48,14 @@ Net::SSH::AuthorizedKey - Virtual Base Class for SSH Public Keys
           # ssh-1 or ssh-2
         print "Key parsed, type is ", $key->type(), "\n";
     } else {
-        die "Cannot parse key (", $key->error(), ")";
+        die "Cannot parse key '$line'";
     }
 
 =head1 DESCRIPTION
 
 Net::SSH::AuthorizedKey is a virtual base class for ssh public keys. 
 Real implementations of it are Net::SSH::AuthorizedKey::SSH1 and
-Net::SSH::AuthorizedKey::SSH2. 
+Net::SSH::AuthorizedKey::SSH2.
 
 The only way to using it directly is by calling its parse() method, and handing
 it an authorized_keys string (aka a line from an authorized_keys file). If it
@@ -63,6 +63,25 @@ recognizes either a ssh-1 or a ssh-2 type key, it will return a
 Net::SSH::AuthorizedKey::SSH1 or a Net::SSH::AuthorizedKey::SSH2 object.
 See their manual pages for instructions on how to use them.
 
+=HEAD2 IMPLEMENTATION REFERENCE
+
+The key parsers implemented in this distribution are implemented similarily
+as the authorized_keys file parser in the openssh source distribution.
+
+Openssh contains the authorized_keys parser
+in its auth2_pubkey.c file. The user_key_allowed2() function opens
+the file and reads it line by line, ignoring leading whitespace, empty
+and comment lines.
+
+After that, if a line doesn't contain a plain key, the parser skips ahead until
+the first whitespace (zooming through quoted areas "..." and interpreting '\"'
+as an escaped quote), then skips this whitespace and tries to read a key one
+more time. 
+
+Regarding options, the Perl parser isn't as elaborate with semantic 
+peculiarities as openssh's auth_parse_options(), but this might be
+added in the future.
+
 =head1 NOTES FOR SUBCLASS DEVELOPERS
 
 If you're just using Net::SSH::AuthorizedKey to parse keys, the
